You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@whimsical.apache.org by se...@apache.org on 2019/05/09 11:24:07 UTC

[whimsy] branch master updated: Temp debug

This is an automated email from the ASF dual-hosted git repository.

sebb pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/whimsy.git


The following commit(s) were added to refs/heads/master by this push:
     new 9113279  Temp debug
9113279 is described below

commit 91132793cff85b729e649e0972c7bbf08bd8a3de
Author: Sebb <se...@apache.org>
AuthorDate: Thu May 9 12:23:54 2019 +0100

    Temp debug
---
 www/secretary/workbench/views/index.js.rb | 9 ++++++++-
 1 file changed, 8 insertions(+), 1 deletion(-)

diff --git a/www/secretary/workbench/views/index.js.rb b/www/secretary/workbench/views/index.js.rb
index cfeda33..f743b21 100644
--- a/www/secretary/workbench/views/index.js.rb
+++ b/www/secretary/workbench/views/index.js.rb
@@ -83,6 +83,9 @@ class Index < Vue
       log 'beforeMount - nomessages'
     end
     self.mergemsgs @@messages if @@messages
+    # temp debug
+    self.merge @@messages if @@messages
+    merge @@messages if @@messages
   end
 
   # on initial load, fetch latest mailbox, subscribe to keyboard and
@@ -158,7 +161,11 @@ class Index < Vue
     }
   end
 
-  # mergemsgs new messages into the list
+  def merge(messages)
+    log 'merge()'
+  end
+
+  # merge new messages into the list
   def mergemsgs(messages)
     log "mergemsgs #{messages.length}"
     messages.each do |new_message|